# A2D-Diary

**A2D-Diary** is a web app that helps you to create multiple-choice questionnaires/diaries that can be marked automatically and transcribed to a digital CSV file. This web app was developed as part of the SKIP project at the Interaction Analysis and Modelling (IAM) Lab of the University of Manchester, UK.  

**For more information check the official docs at [https://a2d-diary.netlify.com/](https://a2d-diary.netlify.com/)**



---
Special mention to the authors of two projects that were adapted and used in this web app: 

- Luke Plant: [https://bitbucket.org/spookylukey/booklet-maker/src](https://bitbucket.org/spookylukey/booklet-maker/src)
- Raphael Baron: [https://github.com/rbaron/omr](https://github.com/rbaron/omr)